@@ -1,11 +1,11 @@
 package Parcel::Track::KR::PostOffice;
-# ABSTRACT: Parcel::Track driver for the ePOST Korea
+# ABSTRACT: Parcel::Track driver for the ePOST Korea (우체국)
 
 use utf8;
 
 use Moo;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 with 'Parcel::Track::Role::Base';
 
@@ -52,8 +52,12 @@ sub track {
         descs  => [],
     );
 
-    my $res = HTTP::Tiny->new( agent => $AGENT )->get( $self->uri );
-    return unless $res->{success};
+    my $http = HTTP::Tiny->new(
+        agent      => $AGENT,
+        verify_SSL => 1,
+    );
+
+    my $res = $http->get( $self->uri );
     unless ( $res->{success} ) {
         $result{result} = 'failed to get parcel tracking info from the site';
         return \%result;
@@ -126,14 +130,16 @@ __END__
 
 =head1 NAME
 
-Parcel::Track::KR::PostOffice - Parcel::Track driver for the ePOST Korea
+Parcel::Track::KR::PostOffice - Parcel::Track driver for the ePOST Korea (ì°ì²´êµ­)
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
+    use Parcel::Track;
+
     # Create a tracker
     my $tracker = Parcel::Track->new( 'KR::PostOffice', '12345-6789-0123' );
 
@@ -146,7 +152,6 @@ version 0.002
     
     # Get the information what you want.
     if ( $result ) {
-        print "Message sent ok\n";
         print "$result->{from}\n";
         print "$result->{to}\n";
         print "$result->{result}\n";
@@ -179,7 +184,7 @@ L<Parcel::Track>
 
 =item *
 
-L<ePOST Korea|http://www.epost.go.kr>
+L<ePOST Korea (우체국)|http://www.epost.go.kr>
 
 =back
 
